@@ -1,4 +1,9 @@
-## Copyright (C) 2007-2019 John W. Eaton and David Bateman
+########################################################################
+##
+## Copyright (C) 2007-2026 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,8 +20,16 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 function plotimages (d, nm, typ)
+
+  if (strcmp (typ , "txt"))
+    image_as_txt (d, nm);
+    return;
+  endif
+
   set_graphics_toolkit ();
   set_print_size ();
   hide_output ();
@@ -30,9 +43,7 @@ function plotimages (d, nm, typ)
     d_typ = ["-d", typ];
   endif
 
-  if (strcmp (typ , "txt"))
-    image_as_txt (d, nm);
-  elseif (strcmp (nm, "plot"))
+  if (strcmp (nm, "plot"))
     x = -10:0.1:10;
     plot (x, sin (x));
     xlabel ("x");
@@ -110,6 +121,26 @@ function plotimages (d, nm, typ)
             '\int_{\fontsize{8}0}^{\fontsize{8}x}} e^{-t^2} dt} = 0.6175']);
       print (outfile, d_typ);
     endif
+  elseif (strcmp (nm, "precisiondate"))
+    rand ("state", 1);
+    t = datenum (2020, 1, 1):(1/1440):datenum (2020, 1, 2);
+    x = -cos (2*pi*t) + rand (size (t)) / 10;
+    subplot (1, 2, 1);
+    plot (t, x);
+    datetick ("x");
+    xlabel ("serial date");
+    title ("problem");
+    subplot (1, 2, 2);
+    plot (t - 730485, x);
+    datetick ("x");
+    xlabel ("2000 years off");
+    title ("workaround");
+    # set wider aspect ratio
+    image_size = [8.25, 3.5]; # in inches, 5:2 format
+    border = 0;              # For postscript use 50/72
+    set (gcf, "papersize", image_size + 2*border);
+    set (gcf, "paperposition", [border, border, image_size]);
+    print (outfile, d_typ);
   else
     error ("unrecognized plot requested");
   endif
@@ -123,11 +154,9 @@ endfunction
 function set_graphics_toolkit ()
   if (isempty (available_graphics_toolkits ()))
     error ("no graphics toolkit available for plotting");
-  elseif (strcmp ("qt", graphics_toolkit ())
-          && __have_feature__ ("QT_OFFSCREEN"))
+  elseif (strcmp ("qt", graphics_toolkit ()))
     ## Use qt with QOffscreenSurface for plot
-  elseif (! strcmp ("gnuplot", graphics_toolkit ()) ...
-          && ! __have_feature__ ("OSMESA"))
+  elseif (! strcmp ("gnuplot", graphics_toolkit ()))
     if (! any (strcmp ("gnuplot", available_graphics_toolkits ())))
       error ("no graphics toolkit available for offscreen plotting");
     else
