@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2023 The Octave Project Developers
+// Copyright (C) 1993-2026 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -30,6 +30,7 @@
 #include <csignal>
 #include <cstdlib>
 
+#include <atomic>
 #include <iostream>
 #include <new>
 
@@ -65,7 +66,7 @@ OCTAVE_BEGIN_NAMESPACE(octave)
 int pipe_handler_error_count = 0;
 
 // TRUE means we can be interrupted.
-bool can_interrupt = false;
+std::atomic<bool> can_interrupt{false};
 
 // TRUE means we should try to enter the debugger on SIGINT.
 bool Vdebug_on_interrupt = false;
@@ -82,7 +83,7 @@ static bool Vsigquit_dumps_octave_core = true;
 static bool Vsigterm_dumps_octave_core = true;
 
 // List of signals we have caught since last call to signal_handler.
-static bool *signals_caught = nullptr;
+static std::atomic<bool> *signals_caught = nullptr;
 
 static void
 my_friendly_exit (int sig, bool save_vars = true)
@@ -107,7 +108,7 @@ my_friendly_exit (int sig, bool save_vars = true)
 // we have caught.
 
 void
-respond_to_pending_signals (void)
+respond_to_pending_signals ()
 {
   // The list of signals is relatively short, so we will just go
   // linearly through the list.
@@ -194,16 +195,15 @@ respond_to_pending_signals (void)
 
   for (int sig = 0; sig < octave_num_signals (); sig++)
     {
-      if (signals_caught[sig])
-        {
-          signals_caught[sig] = false;
+      bool expected = true;
 
+      if (signals_caught[sig].compare_exchange_strong (expected, false))
+        {
           if ((have_sigchld && sig == sigchld)
               || (have_sigcld && sig == sigcld))
             {
               // FIXME: should we block or ignore?
-              volatile interrupt_handler saved_interrupt_handler
-                = ignore_interrupts ();
+              interrupt_handler saved_interrupt_handler = ignore_interrupts ();
 
               void *context = octave_block_child ();
 
@@ -276,7 +276,7 @@ generic_sig_handler (int sig)
   // signal watcher thread so it should probably be more careful about
   // how it accesses global objects.
 
-  octave_signal_caught = 1;
+  octave_signal_caught = true;
 
   signals_caught[sig] = true;
 
@@ -292,11 +292,11 @@ generic_sig_handler (int sig)
       || (have_sigbreak && sig == sigbreak))
     {
       if (! octave_initialized)
-        exit (1);
+        std::exit (EXIT_FAILURE);
 
       if (can_interrupt)
         {
-          octave_signal_caught = 1;
+          octave_signal_caught = true;
           octave_interrupt_state++;
         }
     }
@@ -323,7 +323,7 @@ fpe_sig_handler (int)
 }
 
 interrupt_handler
-catch_interrupts (void)
+catch_interrupts ()
 {
   interrupt_handler retval;
 
@@ -334,7 +334,7 @@ catch_interrupts (void)
 }
 
 interrupt_handler
-ignore_interrupts (void)
+ignore_interrupts ()
 {
   interrupt_handler retval;
 
@@ -345,8 +345,7 @@ ignore_interrupts (void)
 }
 
 interrupt_handler
-set_interrupt_handler (const volatile interrupt_handler& h,
-                       bool restart_syscalls)
+set_interrupt_handler (const interrupt_handler& h, bool restart_syscalls)
 {
   interrupt_handler retval;
 
@@ -362,10 +361,10 @@ set_interrupt_handler (const volatile interrupt_handler& h,
 // Install all the handlers for the signals we might care about.
 
 void
-install_signal_handlers (void)
+install_signal_handlers ()
 {
   if (! signals_caught)
-    signals_caught = new bool [octave_num_signals ()];
+    signals_caught = new std::atomic<bool> [octave_num_signals ()];
 
   for (int i = 0; i < octave_num_signals (); i++)
     signals_caught[i] = false;
@@ -445,7 +444,7 @@ set_sig_struct_field (octave_scalar_map& m, const char *signame)
 }
 
 static octave_scalar_map
-make_sig_struct (void)
+make_sig_struct ()
 {
   octave_scalar_map m;
 
