@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2024 The Octave Project Developers
+// Copyright (C) 1993-2026 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -27,8 +27,6 @@
 #  include "config.h"
 #endif
 
-#include <cassert>
-
 #include <limits>
 
 #include "Array-util.h"
@@ -75,7 +73,7 @@ template <typename T>
 static inline bool
 xisint (T x)
 {
-  return (octave::math::x_nint (x) == x
+  return (octave::math::is_integer (x)
           && x <= std::numeric_limits<int>::max ()
           && x >= std::numeric_limits<int>::min ());
 }
@@ -83,9 +81,18 @@ xisint (T x)
 static inline bool
 xisint (float x)
 {
-  static const float out_of_range_top
-    = static_cast<float> (std::numeric_limits<int>::max ()) + 1.;
-  return (octave::math::x_nint (x) == x
+  static constexpr float out_of_range_top
+    = static_cast<float> (std::numeric_limits<int>::max ()) + 1.0;
+
+  // FIXME: If we return *only* octave::math::is_integer (x)
+  // and delete the lines with numeric_limits<int>,
+  // then that works on MacOS but not on Linux.
+  // A simple test is:    Complex (realmin, realmin) .^ realmax.
+  // On MacOS it gives zero. On Linux it gives Inf - Nani.
+  // If we can make both platforms work without the extra check with
+  // numeric_limits<int>, then we should do so.
+
+  return (octave::math::is_integer (x)
           && x < out_of_range_top
           && x >= std::numeric_limits<int>::min ());
 }
@@ -1259,12 +1266,12 @@ elem_xpow (const NDArray& a, const NDArray& b)
 {
   octave_value retval;
 
-  dim_vector a_dims = a.dims ();
-  dim_vector b_dims = b.dims ();
+  const dim_vector& a_dims = a.dims ();
+  const dim_vector& b_dims = b.dims ();
 
   if (a_dims != b_dims)
     {
-      if (! is_valid_bsxfun ("operator .^", a_dims, b_dims))
+      if (! is_valid_bsxfun (a_dims, b_dims))
         octave::err_nonconformant ("operator .^", a_dims, b_dims);
 
       // Potentially complex results
@@ -1342,12 +1349,12 @@ elem_xpow (const NDArray& a, const Complex& b)
 octave_value
 elem_xpow (const NDArray& a, const ComplexNDArray& b)
 {
-  dim_vector a_dims = a.dims ();
-  dim_vector b_dims = b.dims ();
+  const dim_vector& a_dims = a.dims ();
+  const dim_vector& b_dims = b.dims ();
 
   if (a_dims != b_dims)
     {
-      if (! is_valid_bsxfun ("operator .^", a_dims, b_dims))
+      if (! is_valid_bsxfun (a_dims, b_dims))
         octave::err_nonconformant ("operator .^", a_dims, b_dims);
 
       return bsxfun_pow (a, b);
@@ -1437,12 +1444,12 @@ elem_xpow (const ComplexNDArray& a, double b)
 octave_value
 elem_xpow (const ComplexNDArray& a, const NDArray& b)
 {
-  dim_vector a_dims = a.dims ();
-  dim_vector b_dims = b.dims ();
+  const dim_vector& a_dims = a.dims ();
+  const dim_vector& b_dims = b.dims ();
 
   if (a_dims != b_dims)
     {
-      if (! is_valid_bsxfun ("operator .^", a_dims, b_dims))
+      if (! is_valid_bsxfun (a_dims, b_dims))
         octave::err_nonconformant ("operator .^", a_dims, b_dims);
 
       return bsxfun_pow (a, b);
@@ -1482,12 +1489,12 @@ elem_xpow (const ComplexNDArray& a, const Complex& b)
 octave_value
 elem_xpow (const ComplexNDArray& a, const ComplexNDArray& b)
 {
-  dim_vector a_dims = a.dims ();
-  dim_vector b_dims = b.dims ();
+  const dim_vector& a_dims = a.dims ();
+  const dim_vector& b_dims = b.dims ();
 
   if (a_dims != b_dims)
     {
-      if (! is_valid_bsxfun ("operator .^", a_dims, b_dims))
+      if (! is_valid_bsxfun (a_dims, b_dims))
         octave::err_nonconformant ("operator .^", a_dims, b_dims);
 
       return bsxfun_pow (a, b);
@@ -2579,12 +2586,12 @@ elem_xpow (const FloatNDArray& a, const FloatNDArray& b)
 {
   octave_value retval;
 
-  dim_vector a_dims = a.dims ();
-  dim_vector b_dims = b.dims ();
+  const dim_vector& a_dims = a.dims ();
+  const dim_vector& b_dims = b.dims ();
 
   if (a_dims != b_dims)
     {
-      if (! is_valid_bsxfun ("operator .^", a_dims, b_dims))
+      if (! is_valid_bsxfun (a_dims, b_dims))
         octave::err_nonconformant ("operator .^", a_dims, b_dims);
 
       // Potentially complex results
@@ -2662,12 +2669,12 @@ elem_xpow (const FloatNDArray& a, const FloatComplex& b)
 octave_value
 elem_xpow (const FloatNDArray& a, const FloatComplexNDArray& b)
 {
-  dim_vector a_dims = a.dims ();
-  dim_vector b_dims = b.dims ();
+  const dim_vector& a_dims = a.dims ();
+  const dim_vector& b_dims = b.dims ();
 
   if (a_dims != b_dims)
     {
-      if (! is_valid_bsxfun ("operator .^", a_dims, b_dims))
+      if (! is_valid_bsxfun (a_dims, b_dims))
         octave::err_nonconformant ("operator .^", a_dims, b_dims);
 
       return bsxfun_pow (a, b);
@@ -2757,12 +2764,12 @@ elem_xpow (const FloatComplexNDArray& a, float b)
 octave_value
 elem_xpow (const FloatComplexNDArray& a, const FloatNDArray& b)
 {
-  dim_vector a_dims = a.dims ();
-  dim_vector b_dims = b.dims ();
+  const dim_vector& a_dims = a.dims ();
+  const dim_vector& b_dims = b.dims ();
 
   if (a_dims != b_dims)
     {
-      if (! is_valid_bsxfun ("operator .^", a_dims, b_dims))
+      if (! is_valid_bsxfun (a_dims, b_dims))
         octave::err_nonconformant ("operator .^", a_dims, b_dims);
 
       return bsxfun_pow (a, b);
@@ -2802,12 +2809,12 @@ elem_xpow (const FloatComplexNDArray& a, const FloatComplex& b)
 octave_value
 elem_xpow (const FloatComplexNDArray& a, const FloatComplexNDArray& b)
 {
-  dim_vector a_dims = a.dims ();
-  dim_vector b_dims = b.dims ();
+  const dim_vector& a_dims = a.dims ();
+  const dim_vector& b_dims = b.dims ();
 
   if (a_dims != b_dims)
     {
-      if (! is_valid_bsxfun ("operator .^", a_dims, b_dims))
+      if (! is_valid_bsxfun (a_dims, b_dims))
         octave::err_nonconformant ("operator .^", a_dims, b_dims);
 
       return bsxfun_pow (a, b);
