@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2008-2023 The Octave Project Developers
+// Copyright (C) 2008-2026 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -28,7 +28,8 @@
 
 #define SCALAR float_scalar
 #define SCALARV float_complex
-#define MATRIX float_complex_diag_matrix
+#define DIAG_MATRIX float_complex_diag_matrix
+#define MATRIX float_complex_matrix
 
 #define SSHORT fs
 #define MSHORT fcdm
