@@ -1,47 +1,51 @@
-/*
-
-Copyright (C) 1993-2019 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1993-2026 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
 #endif
 
-#include <cassert>
 #include <cmath>
 
 #include <limits>
 #include <ostream>
 
-#include "Array.h"
+#include "Array-oct.h"
 #include "CollocWt.h"
-#include "lo-error.h"
-#include "lo-mappers.h"
+#include "mappers.h"
+#include "oct-error.h"
 
 // The following routines jcobi, dif, and dfopr are based on the code
-// found in Villadsen, J. and M. L. Michelsen, Solution of Differential
-// Equation Models by Polynomial Approximation, Prentice-Hall (1978)
-// pages 418-420.
+// found in J. Villadsen and M. L. Michelsen, Solution of Differential
+// Equation Models by Polynomial Approximation, Prentice-Hall, 1978,
+// pp. 418-420.
 //
 // Translated to C++ by jwe.
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // Compute the first three derivatives of the node polynomial.
 //
 //                 n0     (alpha,beta)           n1
@@ -55,9 +59,8 @@ along with Octave; see the file COPYING.  If not, see
 // The values of root must be known before a call to dif is possible.
 // They may be computed using jcobi.
 
-static void
-dif (octave_idx_type nt, double *root, double *dif1, double *dif2,
-     double *dif3)
+static void dif (octave_idx_type nt, double *root, double *dif1,
+                 double *dif2, double *dif3)
 {
   // Evaluate derivatives of node polynomial using recursion formulas.
 
@@ -148,15 +151,15 @@ jcobi (octave_idx_type n, octave_idx_type n0, octave_idx_type n1,
        double alpha, double beta, double *dif1, double *dif2,
        double *dif3, double *root)
 {
-  assert (n0 == 0 || n0 == 1);
-  assert (n1 == 0 || n1 == 1);
+  liboctave_panic_unless (n0 == 0 || n0 == 1);
+  liboctave_panic_unless (n1 == 0 || n1 == 1);
 
   octave_idx_type nt = n + n0 + n1;
 
-  assert (nt >= 1);
+  liboctave_panic_unless (nt >= 1);
 
-// -- first evaluation of coefficients in recursion formulas.
-// -- recursion coefficients are stored in dif1 and dif2.
+  // -- first evaluation of coefficients in recursion formulas.
+  // -- recursion coefficients are stored in dif1 and dif2.
 
   double ab = alpha + beta;
   double ad = beta - alpha;
@@ -230,7 +233,7 @@ jcobi (octave_idx_type n, octave_idx_type n0, octave_idx_type n1,
           // Famous last words:  100 iterations should be more than
           // enough in all cases.
 
-          if (++k > 100 || octave::math::isnan (z))
+          if (++k > 100 || math::isnan (z))
             return false;
 
           if (std::abs (z) <= 100 * std::numeric_limits<double>::epsilon ())
@@ -310,17 +313,17 @@ dfopr (octave_idx_type n, octave_idx_type n0, octave_idx_type n1,
        octave_idx_type i, octave_idx_type id, double *dif1,
        double *dif2, double *dif3, double *root, double *vect)
 {
-  assert (n0 == 0 || n0 == 1);
-  assert (n1 == 0 || n1 == 1);
+  liboctave_panic_unless (n0 == 0 || n0 == 1);
+  liboctave_panic_unless (n1 == 0 || n1 == 1);
 
   octave_idx_type nt = n + n0 + n1;
 
-  assert (nt >= 1);
+  liboctave_panic_unless (nt >= 1);
 
-  assert (id == 1 || id == 2 || id == 3);
+  liboctave_panic_unless (id == 1 || id == 2 || id == 3);
 
   if (id != 3)
-    assert (i >= 0 && i < nt);
+    liboctave_panic_unless (i >= 0 && i < nt);
 
   // Evaluate discretization matrices and Gaussian quadrature weights.
   // Quadrature weights are normalized to sum to one.
@@ -384,38 +387,37 @@ CollocWt::error (const char *msg)
 CollocWt&
 CollocWt::set_left (double val)
 {
-  if (val >= rb)
+  if (val >= m_rb)
     error ("CollocWt: left bound greater than right bound");
 
-  lb = val;
-  initialized = 0;
+  m_lb = val;
+  m_initialized = 0;
   return *this;
 }
 
 CollocWt&
 CollocWt::set_right (double val)
 {
-  if (val <= lb)
+  if (val <= m_lb)
     error ("CollocWt: right bound less than left bound");
 
-  rb = val;
-  initialized = 0;
+  m_rb = val;
+  m_initialized = 0;
   return *this;
 }
 
 void
-CollocWt::init (void)
+CollocWt::init ()
 {
   // Check for possible errors.
 
-  double wid = rb - lb;
+  double wid = m_rb - m_lb;
   if (wid <= 0.0)
     {
       error ("CollocWt: width less than or equal to zero");
-      return;
     }
 
-  octave_idx_type nt = n + inc_left + inc_right;
+  octave_idx_type nt = m_n + m_inc_left + m_inc_right;
 
   if (nt < 0)
     error ("CollocWt: total number of collocation points less than zero");
@@ -423,27 +425,28 @@ CollocWt::init (void)
     return;
 
   Array<double> dif1 (dim_vector (nt, 1));
-  double *pdif1 = dif1.fortran_vec ();
+  double *pdif1 = dif1.rwdata ();
 
   Array<double> dif2 (dim_vector (nt, 1));
-  double *pdif2 = dif2.fortran_vec ();
+  double *pdif2 = dif2.rwdata ();
 
   Array<double> dif3 (dim_vector (nt, 1));
-  double *pdif3 = dif3.fortran_vec ();
+  double *pdif3 = dif3.rwdata ();
 
   Array<double> vect (dim_vector (nt, 1));
-  double *pvect = vect.fortran_vec ();
+  double *pvect = vect.rwdata ();
 
-  r.resize (nt, 1);
-  q.resize (nt, 1);
-  A.resize (nt, nt);
-  B.resize (nt, nt);
+  m_r.resize (nt, 1);
+  m_q.resize (nt, 1);
+  m_A.resize (nt, nt);
+  m_B.resize (nt, nt);
 
-  double *pr = r.fortran_vec ();
+  double *pr = m_r.rwdata ();
 
   // Compute roots.
 
-  if (! jcobi (n, inc_left, inc_right, Alpha, Beta, pdif1, pdif2, pdif3, pr))
+  if (! jcobi (m_n, m_inc_left, m_inc_right, m_alpha, m_beta, pdif1,
+               pdif2, pdif3, pr))
     error ("jcobi: newton iteration failed");
 
   octave_idx_type id;
@@ -453,10 +456,11 @@ CollocWt::init (void)
   id = 1;
   for (octave_idx_type i = 0; i < nt; i++)
     {
-      dfopr (n, inc_left, inc_right, i, id, pdif1, pdif2, pdif3, pr, pvect);
+      dfopr (m_n, m_inc_left, m_inc_right, i, id, pdif1, pdif2, pdif3,
+             pr, pvect);
 
       for (octave_idx_type j = 0; j < nt; j++)
-        A(i,j) = vect(j);
+        m_A(i, j) = vect(j);
     }
 
   // Second derivative weights.
@@ -464,19 +468,20 @@ CollocWt::init (void)
   id = 2;
   for (octave_idx_type i = 0; i < nt; i++)
     {
-      dfopr (n, inc_left, inc_right, i, id, pdif1, pdif2, pdif3, pr, pvect);
+      dfopr (m_n, m_inc_left, m_inc_right, i, id, pdif1, pdif2, pdif3,
+             pr, pvect);
 
       for (octave_idx_type j = 0; j < nt; j++)
-        B(i,j) = vect(j);
+        m_B(i, j) = vect(j);
     }
 
   // Gaussian quadrature weights.
 
   id = 3;
-  double *pq = q.fortran_vec ();
-  dfopr (n, inc_left, inc_right, id, id, pdif1, pdif2, pdif3, pr, pq);
+  double *pq = m_q.rwdata ();
+  dfopr (m_n, m_inc_left, m_inc_right, id, id, pdif1, pdif2, pdif3, pr, pq);
 
-  initialized = 1;
+  m_initialized = 1;
 }
 
 std::ostream&
@@ -494,11 +499,13 @@ operator << (std::ostream& os, const CollocWt& a)
 
   os << "\n";
 
-  os << a.Alpha << ' ' << a.Beta << "\n\n"
-     << a.r << "\n\n"
-     << a.q << "\n\n"
-     << a.A << "\n"
-     << a.B << "\n";
+  os << a.m_alpha << ' ' << a.m_beta << "\n\n"
+     << a.m_r << "\n\n"
+     << a.m_q << "\n\n"
+     << a.m_A << "\n"
+     << a.m_B << "\n";
 
   return os;
 }
+
+OCTAVE_END_NAMESPACE(octave)
