@@ -1,36 +1,38 @@
-/*
-
-Copyright (C) 1994-2019 John W. Eaton
-Copyright (C) 2016-2019 Barbara Lócsi
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1994-2026 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
 #endif
 
-#include "Array.h"
-#include "fEIG.h"
+#include "Array-oct.h"
 #include "fColVector.h"
+#include "fEIG.h"
 #include "fMatrix.h"
-#include "lo-error.h"
-#include "lo-lapack-proto.h"
+#include "lapack-proto.h"
+#include "oct-error.h"
 
 octave_idx_type
 FloatEIG::init (const FloatMatrix& a, bool calc_rev, bool calc_lev,
@@ -52,21 +54,21 @@ FloatEIG::init (const FloatMatrix& a, bool calc_rev, bool calc_lev,
   F77_INT info = 0;
 
   FloatMatrix atmp = a;
-  float *tmp_data = atmp.fortran_vec ();
+  float *tmp_data = atmp.rwdata ();
 
   Array<float> wr (dim_vector (n, 1));
-  float *pwr = wr.fortran_vec ();
+  float *pwr = wr.rwdata ();
 
   Array<float> wi (dim_vector (n, 1));
-  float *pwi = wi.fortran_vec ();
+  float *pwi = wi.rwdata ();
 
-  volatile F77_INT nvr = (calc_rev ? n : 0);
+  F77_INT nvr = (calc_rev ? n : 0);
   FloatMatrix vr (nvr, nvr);
-  float *pvr = vr.fortran_vec ();
+  float *pvr = vr.rwdata ();
 
-  volatile F77_INT nvl = (calc_lev ? n : 0);
+  F77_INT nvl = (calc_lev ? n : 0);
   FloatMatrix vl (nvl, nvl);
-  float *pvl = vl.fortran_vec ();
+  float *pvl = vl.rwdata ();
 
   F77_INT lwork = -1;
   float dummy_work;
@@ -75,15 +77,15 @@ FloatEIG::init (const FloatMatrix& a, bool calc_rev, bool calc_lev,
   F77_INT ihi;
 
   Array<float> scale (dim_vector (n, 1));
-  float *pscale = scale.fortran_vec ();
+  float *pscale = scale.rwdata ();
 
   float abnrm;
 
   Array<float> rconde (dim_vector (n, 1));
-  float *prconde = rconde.fortran_vec ();
+  float *prconde = rconde.rwdata ();
 
   Array<float> rcondv (dim_vector (n, 1));
-  float *prcondv = rcondv.fortran_vec ();
+  float *prcondv = rcondv.rwdata ();
 
   F77_INT dummy_iwork;
 
@@ -105,7 +107,7 @@ FloatEIG::init (const FloatMatrix& a, bool calc_rev, bool calc_lev,
 
   lwork = static_cast<F77_INT> (dummy_work);
   Array<float> work (dim_vector (lwork, 1));
-  float *pwork = work.fortran_vec ();
+  float *pwork = work.rwdata ();
 
   F77_XFCN (sgeevx, SGEEVX, (F77_CONST_CHAR_ARG2 (balance ? "B" : "N", 1),
                              F77_CONST_CHAR_ARG2 ("N", 1),
@@ -126,42 +128,42 @@ FloatEIG::init (const FloatMatrix& a, bool calc_rev, bool calc_lev,
   if (info > 0)
     (*current_liboctave_error_handler) ("sgeevx failed to converge");
 
-  lambda.resize (n);
-  v.resize (nvr, nvr);
-  w.resize (nvl, nvl);
+  m_lambda.resize (n);
+  m_v.resize (nvr, nvr);
+  m_w.resize (nvl, nvl);
 
   for (F77_INT j = 0; j < n; j++)
     {
       if (wi.elem (j) == 0.0)
         {
-          lambda.elem (j) = FloatComplex (wr.elem (j));
+          m_lambda.elem (j) = FloatComplex (wr.elem (j));
           for (octave_idx_type i = 0; i < nvr; i++)
-            v.elem (i, j) = vr.elem (i, j);
+            m_v.elem (i, j) = vr.elem (i, j);
 
           for (F77_INT i = 0; i < nvl; i++)
-            w.elem (i, j) = vl.elem (i, j);
+            m_w.elem (i, j) = vl.elem (i, j);
         }
       else
         {
           if (j+1 >= n)
             (*current_liboctave_error_handler) ("EIG: internal error");
 
-          lambda.elem (j) = FloatComplex (wr.elem (j), wi.elem (j));
-          lambda.elem (j+1) = FloatComplex (wr.elem (j+1), wi.elem (j+1));
+          m_lambda.elem (j) = FloatComplex (wr.elem (j), wi.elem (j));
+          m_lambda.elem (j+1) = FloatComplex (wr.elem (j+1), wi.elem (j+1));
 
           for (F77_INT i = 0; i < nvr; i++)
             {
               float real_part = vr.elem (i, j);
               float imag_part = vr.elem (i, j+1);
-              v.elem (i, j) = FloatComplex (real_part, imag_part);
-              v.elem (i, j+1) = FloatComplex (real_part, -imag_part);
+              m_v.elem (i, j) = FloatComplex (real_part, imag_part);
+              m_v.elem (i, j+1) = FloatComplex (real_part, -imag_part);
             }
           for (F77_INT i = 0; i < nvl; i++)
             {
               float real_part = vl.elem (i, j);
               float imag_part = vl.elem (i, j+1);
-              w.elem (i, j) = FloatComplex (real_part, imag_part);
-              w.elem (i, j+1) = FloatComplex (real_part, -imag_part);
+              m_w.elem (i, j) = FloatComplex (real_part, imag_part);
+              m_w.elem (i, j+1) = FloatComplex (real_part, -imag_part);
             }
           j++;
         }
@@ -182,10 +184,10 @@ FloatEIG::symmetric_init (const FloatMatrix& a, bool calc_rev, bool calc_lev)
   F77_INT info = 0;
 
   FloatMatrix atmp = a;
-  float *tmp_data = atmp.fortran_vec ();
+  float *tmp_data = atmp.rwdata ();
 
   FloatColumnVector wr (n);
-  float *pwr = wr.fortran_vec ();
+  float *pwr = wr.rwdata ();
 
   F77_INT lwork = -1;
   float dummy_work;
@@ -201,7 +203,7 @@ FloatEIG::symmetric_init (const FloatMatrix& a, bool calc_rev, bool calc_lev)
 
   lwork = static_cast<F77_INT> (dummy_work);
   Array<float> work (dim_vector (lwork, 1));
-  float *pwork = work.fortran_vec ();
+  float *pwork = work.rwdata ();
 
   F77_XFCN (ssyev, SSYEV, (F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 ("U", 1),
@@ -215,9 +217,9 @@ FloatEIG::symmetric_init (const FloatMatrix& a, bool calc_rev, bool calc_lev)
   if (info > 0)
     (*current_liboctave_error_handler) ("ssyev failed to converge");
 
-  lambda = FloatComplexColumnVector (wr);
-  v = (calc_rev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
-  w = (calc_lev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
+  m_lambda = FloatComplexColumnVector (wr);
+  m_v = (calc_rev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
+  m_w = (calc_lev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
 
   return info;
 }
@@ -242,39 +244,39 @@ FloatEIG::init (const FloatComplexMatrix& a, bool calc_rev, bool calc_lev,
   F77_INT info = 0;
 
   FloatComplexMatrix atmp = a;
-  FloatComplex *tmp_data = atmp.fortran_vec ();
+  FloatComplex *tmp_data = atmp.rwdata ();
 
   FloatComplexColumnVector wr (n);
-  FloatComplex *pw = wr.fortran_vec ();
+  FloatComplex *pw = wr.rwdata ();
 
   F77_INT nvr = (calc_rev ? n : 0);
   FloatComplexMatrix vrtmp (nvr, nvr);
-  FloatComplex *pvr = vrtmp.fortran_vec ();
+  FloatComplex *pvr = vrtmp.rwdata ();
 
   F77_INT nvl = (calc_lev ? n : 0);
   FloatComplexMatrix vltmp (nvl, nvl);
-  FloatComplex *pvl = vltmp.fortran_vec ();
+  FloatComplex *pvl = vltmp.rwdata ();
 
   F77_INT lwork = -1;
   FloatComplex dummy_work;
 
   F77_INT lrwork = 2*n;
   Array<float> rwork (dim_vector (lrwork, 1));
-  float *prwork = rwork.fortran_vec ();
+  float *prwork = rwork.rwdata ();
 
   F77_INT ilo;
   F77_INT ihi;
 
   Array<float> scale (dim_vector (n, 1));
-  float *pscale = scale.fortran_vec ();
+  float *pscale = scale.rwdata ();
 
   float abnrm;
 
   Array<float> rconde (dim_vector (n, 1));
-  float *prconde = rconde.fortran_vec ();
+  float *prconde = rconde.rwdata ();
 
   Array<float> rcondv (dim_vector (n, 1));
-  float *prcondv = rcondv.fortran_vec ();
+  float *prcondv = rcondv.rwdata ();
 
   F77_XFCN (cgeevx, CGEEVX, (F77_CONST_CHAR_ARG2 (balance ? "B" : "N", 1),
                              F77_CONST_CHAR_ARG2 (calc_lev ? "V" : "N", 1),
@@ -294,7 +296,7 @@ FloatEIG::init (const FloatComplexMatrix& a, bool calc_rev, bool calc_lev,
 
   lwork = static_cast<F77_INT> (dummy_work.real ());
   Array<FloatComplex> work (dim_vector (lwork, 1));
-  FloatComplex *pwork = work.fortran_vec ();
+  FloatComplex *pwork = work.rwdata ();
 
   F77_XFCN (cgeevx, CGEEVX, (F77_CONST_CHAR_ARG2 (balance ? "B" : "N", 1),
                              F77_CONST_CHAR_ARG2 (calc_lev ? "V" : "N", 1),
@@ -315,9 +317,9 @@ FloatEIG::init (const FloatComplexMatrix& a, bool calc_rev, bool calc_lev,
   if (info > 0)
     (*current_liboctave_error_handler) ("cgeevx failed to converge");
 
-  lambda = wr;
-  v = vrtmp;
-  w = vltmp;
+  m_lambda = wr;
+  m_v = vrtmp;
+  m_w = vltmp;
 
   return info;
 }
@@ -335,17 +337,17 @@ FloatEIG::hermitian_init (const FloatComplexMatrix& a, bool calc_rev,
   F77_INT info = 0;
 
   FloatComplexMatrix atmp = a;
-  FloatComplex *tmp_data = atmp.fortran_vec ();
+  FloatComplex *tmp_data = atmp.rwdata ();
 
   FloatColumnVector wr (n);
-  float *pwr = wr.fortran_vec ();
+  float *pwr = wr.rwdata ();
 
   F77_INT lwork = -1;
   FloatComplex dummy_work;
 
   F77_INT lrwork = 3*n;
   Array<float> rwork (dim_vector (lrwork, 1));
-  float *prwork = rwork.fortran_vec ();
+  float *prwork = rwork.rwdata ();
 
   F77_XFCN (cheev, CHEEV, (F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 ("U", 1),
@@ -360,7 +362,7 @@ FloatEIG::hermitian_init (const FloatComplexMatrix& a, bool calc_rev,
 
   lwork = static_cast<F77_INT> (dummy_work.real ());
   Array<FloatComplex> work (dim_vector (lwork, 1));
-  FloatComplex *pwork = work.fortran_vec ();
+  FloatComplex *pwork = work.rwdata ();
 
   F77_XFCN (cheev, CHEEV, (F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 ("U", 1),
@@ -375,9 +377,9 @@ FloatEIG::hermitian_init (const FloatComplexMatrix& a, bool calc_rev,
   if (info > 0)
     (*current_liboctave_error_handler) ("cheev failed to converge");
 
-  lambda = FloatComplexColumnVector (wr);
-  v = (calc_rev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
-  w = (calc_lev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
+  m_lambda = FloatComplexColumnVector (wr);
+  m_v = (calc_rev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
+  m_w = (calc_lev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
 
   return info;
 }
@@ -405,7 +407,7 @@ FloatEIG::init (const FloatMatrix& a, const FloatMatrix& b, bool calc_rev,
   F77_INT info = 0;
 
   FloatMatrix tmp = b;
-  float *tmp_data = tmp.fortran_vec ();
+  float *tmp_data = tmp.rwdata ();
   if (! force_qz)
     {
       F77_XFCN (spotrf, SPOTRF, (F77_CONST_CHAR_ARG2 ("L", 1),
@@ -418,27 +420,27 @@ FloatEIG::init (const FloatMatrix& a, const FloatMatrix& b, bool calc_rev,
     }
 
   FloatMatrix atmp = a;
-  float *atmp_data = atmp.fortran_vec ();
+  float *atmp_data = atmp.rwdata ();
 
   FloatMatrix btmp = b;
-  float *btmp_data = btmp.fortran_vec ();
+  float *btmp_data = btmp.rwdata ();
 
   Array<float> ar (dim_vector (n, 1));
-  float *par = ar.fortran_vec ();
+  float *par = ar.rwdata ();
 
   Array<float> ai (dim_vector (n, 1));
-  float *pai = ai.fortran_vec ();
+  float *pai = ai.rwdata ();
 
   Array<float> beta (dim_vector (n, 1));
-  float *pbeta = beta.fortran_vec ();
+  float *pbeta = beta.rwdata ();
 
-  volatile F77_INT nvr = (calc_rev ? n : 0);
+  F77_INT nvr = (calc_rev ? n : 0);
   FloatMatrix vr (nvr, nvr);
-  float *pvr = vr.fortran_vec ();
+  float *pvr = vr.rwdata ();
 
-  volatile F77_INT nvl = (calc_lev ? n : 0);
+  F77_INT nvl = (calc_lev ? n : 0);
   FloatMatrix vl (nvl, nvl);
-  float *pvl = vl.fortran_vec ();
+  float *pvl = vl.rwdata ();
 
   F77_INT lwork = -1;
   float dummy_work;
@@ -457,7 +459,7 @@ FloatEIG::init (const FloatMatrix& a, const FloatMatrix& b, bool calc_rev,
 
   lwork = static_cast<F77_INT> (dummy_work);
   Array<float> work (dim_vector (lwork, 1));
-  float *pwork = work.fortran_vec ();
+  float *pwork = work.rwdata ();
 
   F77_XFCN (sggev, SGGEV, (F77_CONST_CHAR_ARG2 (calc_lev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
@@ -474,45 +476,45 @@ FloatEIG::init (const FloatMatrix& a, const FloatMatrix& b, bool calc_rev,
   if (info > 0)
     (*current_liboctave_error_handler) ("sggev failed to converge");
 
-  lambda.resize (n);
-  v.resize (nvr, nvr);
-  w.resize (nvl, nvl);
+  m_lambda.resize (n);
+  m_v.resize (nvr, nvr);
+  m_w.resize (nvl, nvl);
 
 
   for (F77_INT j = 0; j < n; j++)
     {
       if (ai.elem (j) == 0.0)
         {
-          lambda.elem (j) = FloatComplex (ar.elem (j) / beta.elem (j));
+          m_lambda.elem (j) = FloatComplex (ar.elem (j) / beta.elem (j));
           for (F77_INT i = 0; i < nvr; i++)
-            v.elem (i, j) = vr.elem (i, j);
+            m_v.elem (i, j) = vr.elem (i, j);
 
           for (F77_INT i = 0; i < nvl; i++)
-            w.elem (i, j) = vl.elem (i, j);
+            m_w.elem (i, j) = vl.elem (i, j);
         }
       else
         {
           if (j+1 >= n)
             (*current_liboctave_error_handler) ("EIG: internal error");
 
-          lambda.elem (j) = FloatComplex (ar.elem (j) / beta.elem (j),
-                                          ai.elem (j) / beta.elem (j));
-          lambda.elem (j+1) = FloatComplex (ar.elem (j+1) / beta.elem (j+1),
-                                            ai.elem (j+1) / beta.elem (j+1));
+          m_lambda.elem (j) = FloatComplex (ar.elem (j) / beta.elem (j),
+                                            ai.elem (j) / beta.elem (j));
+          m_lambda.elem (j+1) = FloatComplex (ar.elem (j+1) / beta.elem (j+1),
+                                              ai.elem (j+1) / beta.elem (j+1));
 
           for (F77_INT i = 0; i < nvr; i++)
             {
               float real_part = vr.elem (i, j);
               float imag_part = vr.elem (i, j+1);
-              v.elem (i, j) = FloatComplex (real_part, imag_part);
-              v.elem (i, j+1) = FloatComplex (real_part, -imag_part);
+              m_v.elem (i, j) = FloatComplex (real_part, imag_part);
+              m_v.elem (i, j+1) = FloatComplex (real_part, -imag_part);
             }
           for (F77_INT i = 0; i < nvl; i++)
             {
               float real_part = vl.elem (i, j);
               float imag_part = vl.elem (i, j+1);
-              w.elem (i, j) = FloatComplex (real_part, imag_part);
-              w.elem (i, j+1) = FloatComplex (real_part, -imag_part);
+              m_w.elem (i, j) = FloatComplex (real_part, imag_part);
+              m_w.elem (i, j+1) = FloatComplex (real_part, -imag_part);
             }
           j++;
         }
@@ -540,13 +542,13 @@ FloatEIG::symmetric_init (const FloatMatrix& a, const FloatMatrix& b,
   F77_INT info = 0;
 
   FloatMatrix atmp = a;
-  float *atmp_data = atmp.fortran_vec ();
+  float *atmp_data = atmp.rwdata ();
 
   FloatMatrix btmp = b;
-  float *btmp_data = btmp.fortran_vec ();
+  float *btmp_data = btmp.rwdata ();
 
   FloatColumnVector wr (n);
-  float *pwr = wr.fortran_vec ();
+  float *pwr = wr.rwdata ();
 
   F77_INT lwork = -1;
   float dummy_work;
@@ -564,7 +566,7 @@ FloatEIG::symmetric_init (const FloatMatrix& a, const FloatMatrix& b,
 
   lwork = static_cast<F77_INT> (dummy_work);
   Array<float> work (dim_vector (lwork, 1));
-  float *pwork = work.fortran_vec ();
+  float *pwork = work.rwdata ();
 
   F77_XFCN (ssygv, SSYGV, (1, F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 ("U", 1),
@@ -580,9 +582,9 @@ FloatEIG::symmetric_init (const FloatMatrix& a, const FloatMatrix& b,
   if (info > 0)
     (*current_liboctave_error_handler) ("ssygv failed to converge");
 
-  lambda = FloatComplexColumnVector (wr);
-  v = (calc_rev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
-  w = (calc_lev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
+  m_lambda = FloatComplexColumnVector (wr);
+  m_v = (calc_rev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
+  m_w = (calc_lev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
 
   return info;
 }
@@ -610,7 +612,7 @@ FloatEIG::init (const FloatComplexMatrix& a, const FloatComplexMatrix& b,
   F77_INT info = 0;
 
   FloatComplexMatrix tmp = b;
-  FloatComplex *tmp_data = tmp.fortran_vec ();
+  FloatComplex *tmp_data = tmp.rwdata ();
 
   if (! force_qz)
     {
@@ -624,31 +626,31 @@ FloatEIG::init (const FloatComplexMatrix& a, const FloatComplexMatrix& b,
     }
 
   FloatComplexMatrix atmp = a;
-  FloatComplex *atmp_data = atmp.fortran_vec ();
+  FloatComplex *atmp_data = atmp.rwdata ();
 
   FloatComplexMatrix btmp = b;
-  FloatComplex *btmp_data = btmp.fortran_vec ();
+  FloatComplex *btmp_data = btmp.rwdata ();
 
   FloatComplexColumnVector alpha (n);
-  FloatComplex *palpha = alpha.fortran_vec ();
+  FloatComplex *palpha = alpha.rwdata ();
 
   FloatComplexColumnVector beta (n);
-  FloatComplex *pbeta = beta.fortran_vec ();
+  FloatComplex *pbeta = beta.rwdata ();
 
   F77_INT nvr = (calc_rev ? n : 0);
   FloatComplexMatrix vrtmp (nvr, nvr);
-  FloatComplex *pvr = vrtmp.fortran_vec ();
+  FloatComplex *pvr = vrtmp.rwdata ();
 
   F77_INT nvl = (calc_lev ? n : 0);
   FloatComplexMatrix vltmp (nvl, nvl);
-  FloatComplex *pvl = vltmp.fortran_vec ();
+  FloatComplex *pvl = vltmp.rwdata ();
 
   F77_INT lwork = -1;
   FloatComplex dummy_work;
 
   F77_INT lrwork = 8*n;
   Array<float> rwork (dim_vector (lrwork, 1));
-  float *prwork = rwork.fortran_vec ();
+  float *prwork = rwork.rwdata ();
 
   F77_XFCN (cggev, CGGEV, (F77_CONST_CHAR_ARG2 (calc_lev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
@@ -665,7 +667,7 @@ FloatEIG::init (const FloatComplexMatrix& a, const FloatComplexMatrix& b,
 
   lwork = static_cast<F77_INT> (dummy_work.real ());
   Array<FloatComplex> work (dim_vector (lwork, 1));
-  FloatComplex *pwork = work.fortran_vec ();
+  FloatComplex *pwork = work.rwdata ();
 
   F77_XFCN (cggev, CGGEV, (F77_CONST_CHAR_ARG2 (calc_lev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
@@ -683,13 +685,13 @@ FloatEIG::init (const FloatComplexMatrix& a, const FloatComplexMatrix& b,
   if (info > 0)
     (*current_liboctave_error_handler) ("cggev failed to converge");
 
-  lambda.resize (n);
+  m_lambda.resize (n);
 
   for (F77_INT j = 0; j < n; j++)
-    lambda.elem (j) = alpha.elem (j) / beta.elem (j);
+    m_lambda.elem (j) = alpha.elem (j) / beta.elem (j);
 
-  v = vrtmp;
-  w = vltmp;
+  m_v = vrtmp;
+  m_w = vltmp;
 
   return info;
 }
@@ -714,20 +716,20 @@ FloatEIG::hermitian_init (const FloatComplexMatrix& a,
   F77_INT info = 0;
 
   FloatComplexMatrix atmp = a;
-  FloatComplex *atmp_data = atmp.fortran_vec ();
+  FloatComplex *atmp_data = atmp.rwdata ();
 
   FloatComplexMatrix btmp = b;
-  FloatComplex *btmp_data = btmp.fortran_vec ();
+  FloatComplex *btmp_data = btmp.rwdata ();
 
   FloatColumnVector wr (n);
-  float *pwr = wr.fortran_vec ();
+  float *pwr = wr.rwdata ();
 
   F77_INT lwork = -1;
   FloatComplex dummy_work;
 
   F77_INT lrwork = 3*n;
   Array<float> rwork (dim_vector (lrwork, 1));
-  float *prwork = rwork.fortran_vec ();
+  float *prwork = rwork.rwdata ();
 
   F77_XFCN (chegv, CHEGV, (1, F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 ("U", 1),
@@ -743,7 +745,7 @@ FloatEIG::hermitian_init (const FloatComplexMatrix& a,
 
   lwork = static_cast<F77_INT> (dummy_work.real ());
   Array<FloatComplex> work (dim_vector (lwork, 1));
-  FloatComplex *pwork = work.fortran_vec ();
+  FloatComplex *pwork = work.rwdata ();
 
   F77_XFCN (chegv, CHEGV, (1, F77_CONST_CHAR_ARG2 (calc_rev ? "V" : "N", 1),
                            F77_CONST_CHAR_ARG2 ("U", 1),
@@ -759,9 +761,9 @@ FloatEIG::hermitian_init (const FloatComplexMatrix& a,
   if (info > 0)
     (*current_liboctave_error_handler) ("zhegv failed to converge");
 
-  lambda = FloatComplexColumnVector (wr);
-  v = (calc_rev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
-  w = (calc_lev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
+  m_lambda = FloatComplexColumnVector (wr);
+  m_v = (calc_rev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
+  m_w = (calc_lev ? FloatComplexMatrix (atmp) : FloatComplexMatrix ());
 
   return info;
 }
