@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2000-2025 The Octave Project Developers
+## Copyright (C) 2000-2026 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -43,9 +43,9 @@
 ## @example
 ## @group
 ## polygcd (poly (1:8), poly (3:12)) - poly (3:8)
-## @result{} [ 0, 0, 0, 0, 0, 0, 0 ]
+## @xresult{} [ 0, 0, 0, 0, 0, 0, 0 ]
 ## deconv (poly (1:8), polygcd (poly (1:8), poly (3:12))) - poly (1:2)
-## @result{} [ 0, 0, 0 ]
+## @xresult{} [ 0, 0, 0 ]
 ## @end group
 ## @end example
 ## @seealso{poly, roots, conv, deconv, residue}
