@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2006-2020 The Octave Project Developers
+## Copyright (C) 2006-2026 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,7 +24,7 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} strtrunc (@var{s}, @var{n})
+## @deftypefn {} {@var{s} =} strtrunc (@var{s}, @var{n})
 ## Truncate the character string @var{s} to length @var{n}.
 ##
 ## If @var{s} is a character matrix, then the number of columns is adjusted.
@@ -78,7 +78,7 @@ endfunction
 %! assert (y{2}, repmat ("line", 2, 1));
 
 ## Test input validation
-%!error strtrunc ()
+%!error <Invalid call> strtrunc ()
 %!error strtrunc ("abcd")
 %!error strtrunc ("abcd", 4, 5)
 %!error <N must be a positive integer> strtrunc ("abcd", ones (2,2))
