@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2010-2025 The Octave Project Developers
+## Copyright (C) 2010-2026 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -66,7 +66,7 @@ function str = untabify (t, tw = 8, deblank_arg = false)
   if (ischar (t))
     str = replace_tabs (t, tw);
   else
-    str = cellfun (@replace_tabs, t, {tw}, "uniformoutput", false);
+    str = cellfun ('replace_tabs', t, {tw}, "uniformoutput", false);
   endif
 
   if (deblank_arg)
